@@ -9,13 +9,15 @@ use Carp ();
 
 use parent 'Data::Object::Base';
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 # BUILD
 
 sub new {
   my ($class, $data) = @_;
 
+  $data //= [];
+
   if (Scalar::Util::blessed($data) && $data->can('detract')) {
     $data = $data->detract;
   }
@@ -53,7 +55,9 @@ Data-Object Abstract Array Class
 
 =head1 DESCRIPTION
 
-This package provides routines for operating on Perl 5 array references.
+This package provides routines for operating on Perl 5 array references. If no
+argument is provided, this package is instantiated with a default value of
+C<[]>.
 
 =cut
 
@@ -104,9 +108,9 @@ instance.
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
