@@ -16,7 +16,7 @@ require Data::Object::Scalar::Autobox;
 require Data::Object::String::Autobox;
 require Data::Object::Undef::Autobox;
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 sub import {
   my ($class) = @_;
@@ -92,9 +92,9 @@ L<Data::Object::Library>
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
