@@ -10,19 +10,21 @@ use Scalar::Util ();
 
 use parent 'Data::Object::Base';
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 # BUILD
 
 sub new {
   my ($class, $data) = @_;
 
+  $data //= '0.0';
+
   if (Scalar::Util::blessed($data) && $data->can('detract')) {
     $data = $data->detract;
   }
 
   if (defined($data)) {
-    $data =~ s/^\+//; # not keen on this but ...
+    $data =~ s/^\+//;
   }
 
   if (!defined($data) || ref($data)) {
@@ -64,7 +66,9 @@ Data-Object Abstract Float Class
 
 =head1 DESCRIPTION
 
-This package provides routines for operating on Perl 5 floating-point data.
+This package provides routines for operating on Perl 5 floating-point data. If
+no argument is provided, this package is instantiated with a default value of
+C<0.00>.
 
 =cut
 
@@ -114,9 +118,9 @@ The new method expects a floating-point number and returns a new class instance.
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
