@@ -10,13 +10,15 @@ use Scalar::Util ();
 
 use parent 'Data::Object::Base';
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 # BUILD
 
 sub new {
   my ($class, $data) = @_;
 
+  $data //= 0;
+
   if (Scalar::Util::blessed($data) && $data->can('detract')) {
     $data = $data->detract;
   }
@@ -66,7 +68,9 @@ Data-Object Abstract Number Class
 
 =head1 DESCRIPTION
 
-This package provides routines for operating on Perl 5 numeric data.
+This package provides routines for operating on Perl 5 numeric data. If no
+argument is provided, this package is instantiated with a default value of
+C<0>.
 
 =cut
 
@@ -116,9 +120,9 @@ The new method expects a number and returns a new class instance.
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
