@@ -8,7 +8,7 @@ use warnings;
 use Moo::Role;
 use Readonly;
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 # METHODS
 
@@ -92,9 +92,9 @@ is made to modify the underlying value.
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
