@@ -7,7 +7,7 @@ use warnings;
 
 use Moo::Role;
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 requires 'eq';
 requires 'gt';
@@ -55,9 +55,9 @@ L<Data::Object::Library>
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
