@@ -9,7 +9,7 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Func';
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 # BUILD
 # METHODS
@@ -61,9 +61,9 @@ L<Data::Object::Library>
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
