@@ -7,7 +7,7 @@ use warnings;
 
 use Scalar::Util ();
 
-our $VERSION = '1.60'; # VERSION
+our $VERSION = '1.70'; # VERSION
 
 # FUNCTIONS
 
@@ -763,9 +763,9 @@ the provided data type and can be used to perform operations on the data.
 
 =head1 CREDITS
 
-Al Newkirk, C<awncorp@cpan.org>, C<+284>
+Al Newkirk, C<+287>
 
-Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>
+Anthony Brummett, C<+10>
 
 =cut
 
